//
//  PizarraView.swift
//  Pizarra
//
//  Created by Santiago Pavón on 10/6/15.
//  Copyright (c) 2015 UPM. All rights reserved.
//

import UIKit

protocol PizarraDataSource: class {
    func endIndex() -> Int
    func point(at index: Int) -> CGPoint
}

@IBDesignable
class PizarraView: UIView {

    @IBInspectable
    var pathWidth: CGFloat = 3.0
    
    @IBInspectable
    var pathColor: UIColor = UIColor.red
    
    weak var dataSource: PizarraDataSource!
    
    override func draw(_ rect: CGRect) {
        
        guard dataSource.endIndex() > 0 else { return }
        
        let path = UIBezierPath()

        path.move(to: dataSource.point(at: 0))
        for t in 0..<dataSource.endIndex() {
            path.addLine(to: dataSource.point(at: t))
        }
        
        path.lineWidth = pathWidth
        pathColor.set()
        path.stroke()
    }
    
    
    #if TARGET_INTERFACE_BUILDER
    class FakeDataSource : PizarraDataSource {
    
        func endIndex() -> Int {return 100}
    
        func point(at index: Int) -> CGPoint {
            return CGPoint(x: index, y: index % 25)
        }
    }
    
    var strongDataSource: PizarraDataSource!
    
    override func prepareForInterfaceBuilder() {
        strongDataSource = FakeDataSource()
        dataSource = strongDataSource
    }
    #endif
    

}
